========
numpy_nn
========


.. image:: https://img.shields.io/pypi/v/numpy_nn.svg
        :target: https://pypi.org/project/numpy-nn/0.1.0/

.. image:: https://img.shields.io/travis/rahuldshetty/numpy_nn.svg
        :target: https://travis-ci.com/rahuldshetty/numpy_nn

.. image:: https://readthedocs.org/projects/numpy-nn/badge/?version=latest
        :target: https://numpy-nn.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/rahuldshetty/numpy_nn/shield.svg
     :target: https://pyup.io/repos/github/rahuldshetty/numpy_nn/
     :alt: Updates



Numpy NN is a Deep Neural Network Package which is built on base Numpy operations. This project is under development and any contributions are welcome.


* Free software: MIT license
* Documentation: https://numpy-nn.readthedocs.io.


Features
--------
* Layers: (Neurons)
* Losses: (Mean Absolute Error, Mean Squared Error)
* Optimizer: (Stochastic Gradient Descent)
* Activation: (ReLU, TanH, Sigmoid)
* Layer Abstraction to implement custom activations and layers

TODO
--------
* Implementation of different Losses
* Distributed Computation or GPU utilization
* Dataset processing utilities


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
